@@ -175,6 +175,13 @@ class Storage:
         if 'fki_record_id' in data:
             self.fki_record_id = data['fki_record_id']
 
+class Device:
+    def __init__(self):
+        self.uuid = None
+
+    def from_json(self, data):
+        if 'uuid' in data:
+            self.uuid = data['uuid']
 
 class FramesManager:
     def __init__(self):
@@ -245,6 +252,13 @@ class FramesManager:
         w.from_json(self._get(uri))
         return w
 
+    def get_device(self, uuid: str) -> Device:
+        uri = "{}/device/{}".format(self.url, uuid)
+
+        d = Device()
+        d.from_json(self._get(uri))
+        return d
+
 
 if __name__ == "__main__":
     fm = FramesManager()
